pywr.parameters.ArrayIndexedScenarioParameter — Pywr 0.5dev documentation

# pywr.parameters.ArrayIndexedScenarioParameter

class `pywr.parameters.` `ArrayIndexedScenarioParameter`

  A Scenario varying Parameter

  The values in this parameter are vary in time based on index and vary within a single Scenario.

  `__init__`()

    values should be an iterable that is the same length as scenario.size

  Methods

  `after` |
  `before` |
  `finish` |
  `get_all_values` |
  `get_double_lower_bounds` |
  `get_double_upper_bounds` |
  `get_double_variables` |
  `get_integer_lower_bounds` |
  `get_integer_upper_bounds` |
  `get_integer_variables` |
  `get_value` |
  `load` |
  `lower_bounds` |
  `register` |
  `reset` |
  `set_double_variables` |
  `set_integer_variables` |
  `setup` |
  `unregister` |
  `update` |
  `upper_bounds` |
  `value` |

  Attributes

  `children` |
  `comment` |
  `double_size` |
  `integer_size` |
  `is_variable` |
  `model` |
  `name` |
  `parents` |
  `size` |